<?php
if (!isset($gCms)) exit;

if (! $this->CheckPermission('Use MetaMax')) {
  return $this->DisplayErrorPage($id, $params, $returnid,$this->Lang('accessdenied'));
}

echo $this->StartTabHeaders();
if (FALSE == empty($params['active_tab']))
  {
    $tab = $params['active_tab'];
  } else {
  $tab = '';
 }

if ($this->CheckPermission('Set MetaMax Prefs'))
   {
   echo $this->SetTabHeader('meta',$this->Lang('tab_mod_meta'), ('meta' == $tab)?true:false);
   echo $this->SetTabHeader('html',$this->Lang('tab_mod_html'), ('html' == $tab)?true:false);
   echo $this->SetTabHeader('css',$this->Lang('tab_mod_css'), ('css' == $tab)?true:false);
   echo $this->SetTabHeader('jquery',$this->Lang('tab_mod_jquery'), ('jquery' == $tab)?true:false);
   echo $this->SetTabHeader('keywords',$this->Lang('tab_mod_keywords'), ('keywords' == $tab)?true:false);
   echo $this->SetTabHeader('analytics',$this->Lang('tab_mod_analytics'), ('analytics' == $tab)?true:false);
   }
echo $this->EndTabHeaders();


echo $this->StartTabContent();
if ($this->CheckPermission('Use MetaMax') )
  {
    echo $this->StartTab('meta', $params);
    include(dirname(__FILE__).'/function.admin_metatab.php');
    echo $this->EndTab();
    echo $this->StartTab('html', $params);
    include(dirname(__FILE__).'/function.admin_htmltab.php');
    echo $this->EndTab();
    echo $this->StartTab('css', $params);
    include(dirname(__FILE__).'/function.admin_csstab.php');
    echo $this->EndTab();
    echo $this->StartTab('jquery', $params);
    include(dirname(__FILE__).'/function.admin_jquerytab.php');
    echo $this->EndTab();
    echo $this->StartTab('keywords', $params);
    include(dirname(__FILE__).'/function.admin_keywordstab.php');
    echo $this->EndTab();
    echo $this->StartTab('analytics', $params);
    include(dirname(__FILE__).'/function.admin_analyticstab.php');
    echo $this->EndTab();
  }

echo $this->EndTabContent();
?>